#! /usr/bin/python3 -s

import argparse
import json
import logging
from p2.logging import HttpLogger
from p2.tools.driver import get_driver


parser = argparse.ArgumentParser()
parser.add_argument("--driver", help="p2.loader driver to use", required=True)
parser.add_argument("args", help="p2.loader driver params as json snippet",
                    nargs='*')

args = parser.parse_args()

driver = args.driver
params = dict(arg.split(':') for arg in args.args)

driver_obj = get_driver(driver=driver, module='p2.loader', class_name='Loader', **params)

log = HttpLogger(
    level = logging.DEBUG,
    silent = False,
    name='p2.loader.'+driver,
)
logger = log.getLogger()

try:
    logger.info(f"Loading resources using the {driver} driver...")
    logger.info(f"Input params: {params}")
    driver_obj.get_resources()
    driver_obj.sync_resources()
except Exception as e:
    logger.error(f"Error loading resources: {e}")
